@@ -32,10 +32,16 @@ def every_frame(frame_count=0):
         yield dt
         pygame.display.flip()
 
-
+_is_quit = False
 def is_quit():
+    global _is_quit
+
+    if _is_quit :
+        return True
+
     for event in pygame.event.get():
         if event.type == pygame.QUIT:
+            _is_quit = True
             return True
     return False
 
